@@ -198,10 +198,8 @@ def process_line(calc_line, local_ns):
     equation = alt_sqrt(equation)
 
     # Handle manually inserted line breaks placed in the line by the user
-    description.replace('//', '////')
-    equation.replace('//', '')
-    latex_equation.replace('//', '////')
-    reference.replace('//', '////')
+    description = description.replace('\\\\', '} \\\\ \\textsf{')
+    equation = equation.replace('\\\\', '')
     
     # Turn off pretty printing momentarily while we prepare a Python expression for the value
     ureg.default_format = '~'
@@ -323,6 +321,8 @@ def process_line(calc_line, local_ns):
     # There will be a double equals sign if the equation is not being displayed
     latex_text = latex_text.replace('==', '=')
     
+    print(latex_text)
+
     return latex_text
 
 #%%
